@@ -2,7 +2,7 @@ package RedisDB;
 
 use warnings;
 use strict;
-our $VERSION = "0.30_2";
+our $VERSION = "0.30_3";
 $VERSION = eval $VERSION;
 
 use RedisDB::Error;
@@ -91,7 +91,7 @@ sub new {
     $self->{_replies}       = [];
     $self->{_callbacks}     = [];
     $self->{_to_be_fetched} = 0;
-    $self->{database} //= 0;
+    $self->{database} ||= 0;
     $self->_connect unless $self->{lazy};
     return $self;
 }
